==> vamos-0.5.3.tar.gz: vamos-0.5.3/caelum/Sky.h <==
//  Sky.cc - Helper class for Caelum.
//
//  Copyright (C) 2003 Sam Varner
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _SKY_H_
#define _SKY_H_

#include <string>

#include <sigc++/sigc++.h>

#include <vamos/geometry/Gl_Texture_Image.h>

class Sky : public SigC::Object
{
  // The size of the viewports.
  int m_width;
  int m_height;
  
  // The texture image.
  Vamos_Geometry::Gl_Texture_Image* mp_image;

protected:
  // Render a view.
  virtual void draw () = 0;

public:
  // image - the name of the image file.
  // width - the width of each viewport.
  // height - the height of each viewport.
  Sky (std::string image, int width, int height);
  
  // Respond to keystrokes.
  virtual void key_press (unsigned char key, int, int);
  virtual void special_key_press (int key, int, int) {};

  // Render the entire scene.
  void display ();
};

#endif // not _SKY_H_

==> vamos-0.5.5.tar.gz: vamos-0.5.5/caelum/Sky.h <==
//  Sky.cc - Helper class for Caelum.
//
//  Copyright (C) 2003 Sam Varner
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef _SKY_H_
#define _SKY_H_

#include <string>

#include <sigc++/sigc++.h>

#include <vamos/media/Texture_Image.h>

class Sky : public SigC::Object
{
  // The size of the viewports.
  int m_width;
  int m_height;
  
  // The texture image.
  Vamos_Media::Texture_Image* mp_image;

protected:
  // Render a view.
  virtual void draw () = 0;

public:
  // image - the name of the image file.
  // width - the width of each viewport.
  // height - the height of each viewport.
  Sky (std::string image, int width, int height);
  
  // Respond to keystrokes.
  virtual void key_press (unsigned char key, int, int);
  virtual void special_key_press (int key, int, int) {};

  // Render the entire scene.
  void display ();
};

#endif // not _SKY_H_
